#################################################################################
################### Supplemental File S3 - Data Analysis ########################
############################ Berg et al 2021 ####################################
#################################################################################

#####################################
## Mass Spectrometry Data Analysis ##
#####################################

## Searching for proline to alanine subsitutions in all strains ##

## Raw files were searched agains the S. cerevisiae protein sequence database using Comet (release 2015.01)
## with constant modification of cysteine carbamidomethylation and variable modification of methionine oxidation and proline to alanine
## and filtered to a false discovery rate of 1% at the peptide spectrum match level using Percolator 

# Read in data
setwd("C:/Users/Matt/Desktop/PostDoc - Villen Lab/2021.03 - Mistranslation in SGA strains")
PtoA <- read.csv("20210411_PtoAMistranslationIDs_ZucchiniOutput.csv", header=TRUE, sep = ",")

# Packages needed for analysis
library(tidyverse)
library(tidyr)
library(dplyr)
library(stringr)

# Clean up data and aggregate to the peptide level
# (1 - Mutate) Add columns to annotate strain and replicate information, trim extra characters from sequence, replace modification symbols (* = [ox], # = [ac], @ = [mut]), count mutations per peptide, annotate mistranslation type, create column with WT peptide sequence, specify if peptide is WT or mistranslated
# (2 - Filter) Remove Decoys
# (3 - Group) Aggregate to peptide from PSM level
PtoA.Peptide <- PtoA %>%
  mutate(strain = str_sub(Sample.Name, start = -8, end = -3),
         replicate = str_sub(Sample.Name, start = -1),
         trimSeq = str_sub(Sequence, start = 3, end = str_length(Sequence)-2),
         trimSeq = str_replace_all(trimSeq, "[*]", "[ox]"),
         trimSeq = str_replace_all(trimSeq, "#", "[ac]"),
         trimSeq = str_replace_all(trimSeq, "@", "[mut]"),
         numMut = str_count(trimSeq, "[mut]"),
         mutation =  "P to A",
         targetAA = str_sub(mutation, start = 1, end = 1),
         wtSequence = str_replace_all(trimSeq, "\\[mut\\]", ""),
         pepType = if_else(numMut>0, "mutant", "WT")) %>%
  filter(!grepl("DECOY", Reference)) %>%
  distinct(Sample.Name, strain, replicate, Reference, trimSeq, numMut, mutation, targetAA, wtSequence, pepType)

# Filter out mutant peptides where the WT peptide was no observed
# Seperate WT peptides from mistranslated peptides
PtoA.WT.Peptides <- PtoA.Peptide %>%
  ungroup() %>%
  filter(pepType == "WT") %>%
  select(strain, replicate, Sample.Name, Reference, trimSeq, wtSequence, pepType)

PtoA.Mistranslated.Peptides <- PtoA.Peptide %>%
  ungroup() %>%
  filter(pepType == "mutant") %>%
  select(strain, replicate, Sample.Name, Reference, trimSeq, wtSequence, pepType)

# Join to filter out any mutant peptide with no WT counterpart
PtoA.Filtered.MistranslatedPeptides <- left_join(PtoA.WT.Peptides, PtoA.Mistranslated.Peptides, by = c("strain", "replicate", "Sample.Name", "wtSequence"), suffix = c(".wt", ".mut"))

# Calculate the percent mistranslation based on IDs
# (1 - Filter) Remove peptides that don't contain proline
# (2 - Select) Only take the needed columns
# (3 - Group) Group the data by strain and replicate
# (4 - Summarise) Count the number of WT peptides for each strain/replicate and the number of mistranslated peptides
PtoA.PercentMistranslation <- PtoA.Filtered.MistranslatedPeptides %>%
  filter(str_detect(wtSequence, "P")) %>%
  select(strain, replicate, pepType.wt, pepType.mut, Sample.Name) %>%
  group_by(strain, replicate, Sample.Name) %>%
  summarise(countWT = n(), countMutant = sum(!is.na(pepType.mut))) %>%
  mutate(PercentMistranslation = (countMutant/countWT)*100,
         MistranslationEvent = "P to A")


## Searching for arginine to serine subsitutions in all strains ##

## Raw files were searched agains the S. cerevisiae protein sequence database using Comet (release 2015.01)
## with constant modification of cysteine carbamidomethylation and variable modification of methionine oxidation and arginine to serine
## and filtered to a false discovery rate of 1% at the peptide spectrum match level using Percolator 

# Read in data
setwd("C:/Users/Matt/Desktop/PostDoc - Villen Lab/2021.03 - Mistranslation in SGA strains")
RtoS <- read.csv("20210411_RtoSMistranslationIDs_ZucchiniOutput.csv", header=TRUE, sep = ",")

# Clean up data and aggregate to the peptide level
# (1 - Mutate) Add columns to annotate strain and replicate information, trim extra characters from sequence, replace modification symbols (* = [ox], # = [ac], @ = [mut]), count mutations per peptide, annotate mistranslation type, create column with WT peptide sequence, specify if peptide is WT or mistranslated
# (2 - Filter) Remove Decoys
# (3 - Group) Aggregate to peptide from PSM level
RtoS.Peptide <- RtoS %>%
  mutate(strain = str_sub(Sample.Name, start = -8, end = -3),
         replicate = str_sub(Sample.Name, start = -1),
         trimSeq = str_sub(Sequence, start = 3, end = str_length(Sequence)-2),
         trimSeq = str_replace_all(trimSeq, "[*]", "[ox]"),
         trimSeq = str_replace_all(trimSeq, "#", "[ac]"),
         trimSeq = str_replace_all(trimSeq, "@", "[mut]"),
         numMut = str_count(trimSeq, "[mut]"),
         mutation =  "R to S",
         targetAA = str_sub(mutation, start = 1, end = 1),
         wtSequence = str_replace_all(trimSeq, "\\[mut\\]", ""),
         pepType = if_else(numMut>0, "mutant", "WT")) %>%
  filter(!grepl("DECOY", Reference)) %>%
  distinct(Sample.Name, strain, replicate, Reference, trimSeq, numMut, mutation, targetAA, wtSequence, pepType)

# Filter out mutant peptides where the WT peptide was no observed
# Seperate WT peptides from mistranslated peptides
RtoS.WT.Peptides <- RtoS.Peptide %>%
  ungroup() %>%
  filter(pepType == "WT") %>%
  select(strain, replicate, Sample.Name, Reference, trimSeq, wtSequence, pepType)

RtoS.Mistranslated.Peptides <- RtoS.Peptide %>%
  ungroup() %>%
  filter(pepType == "mutant") %>%
  select(strain, replicate, Sample.Name, Reference, trimSeq, wtSequence, pepType)

# Join to filter out any mutant peptide with no WT counterpart
RtoS.Filtered.MistranslatedPeptides <- left_join(RtoS.WT.Peptides, RtoS.Mistranslated.Peptides, by = c("strain", "replicate", "Sample.Name", "wtSequence"), suffix = c(".wt", ".mut"))

# Calculate the percent mistranslation based on IDs
# (1 - Filter) Remove peptides that don't contain proline
# (2 - Select) Only take the needed columns
# (3 - Group) Group the data by strain and replicate
# (4 - Summarise) Count the number of WT peptides for each strain/replicate and the number of mistranslated peptides
RtoS.PercentMistranslation <- RtoS.Filtered.MistranslatedPeptides %>%
  filter(str_detect(wtSequence, "R")) %>%
  select(strain, replicate, pepType.wt, pepType.mut, Sample.Name) %>%
  group_by(strain, replicate, Sample.Name) %>%
  summarise(countWT = n(), countMutant = sum(!is.na(pepType.mut))) %>%
  mutate(PercentMistranslation = (countMutant/countWT)*100,
         MistranslationEvent = "R to S")


##################################
## RNA Sequencing Data Analysis ##
##################################

## Raw sequencing data was trimmed using Trimmomatic,
## aligned to the S. cerevisiae S288C reference genome (release R64-2-1_20150113) using STAR 
## and read counts for each gene were summarized using featureCounts

# Read in data from featureCounts 
# and file to link yeast systematic names with common names from SGD
setwd("C:/Users/Matt/Desktop/2020.01 - SGA Screen Paper/2020.10 - RNA Sequencing on SGA Strains")
data <- read.table("MistranslatingtRNA_RNAseq_RawCounts.txt", header = T, sep = "\t")
GeneNames <- read.delim("NEW_Yeast_GeneNames.txt", header = T, sep = "\t")

# Packages needed for analysis
library(tidyverse)
library(compositions)
library(zCompositions)
library(pheatmap)
library(RColorBrewer)
library(ggsci)
library(ggrepel)
library(ggplot2)
library(DESeq2)
library(VennDiagram)

# Add together counts from paired and unpaired reads and select only columns of interest
RawCounts <- data %>%
  mutate(WT13 = WT_13a_single + WT_13a_paired,
         WT15 = WT_15a_single + WT_15a_paired,
         WT16 = WT_16a_single + WT_16a_paired,
         ProAla2 = ProAla_2a_single + ProAla_2a_paired,
         ProAla3 = ProAla_3a_single + ProAla_3a_paired,
         ProAla4 = ProAla_4a_single + ProAla_4a_paired,
         ArgSer5 = ArgSer_5a_single + ArgSer_5a_paired,
         ArgSer6 = ArgSer_6a_single + ArgSer_6a_paired,
         ArgSer7 = ArgSer_7a_single + ArgSer_7a_paired) %>%
  dplyr::rename(Systematic = Geneid) %>%
  dplyr::select(Systematic, 
                WT13, 
                WT15, 
                WT16, 
                ProAla2, 
                ProAla3, 
                ProAla4,
                ArgSer5,
                ArgSer6,
                ArgSer7)


## PCA Analysis ##

# Prepare data for CLR Transformation
clr <- RawCounts
rownames(clr) <- clr$Systematic
clr <- clr[-1]

# Remove rows with all 0 counts
clr.gt0 <- clr[apply(clr,1,sum) > 0,] 

# Estimate 0 values
clr.n0 <- cmultRepl(t(clr.gt0), method = "CZM", label = 0)

# CLR transformation
clr.n0.trans <- t(apply(clr.n0, 1, function(x){log2(x) - mean(log2(x))})) 

# Create PCA plot
pcx <- prcomp(clr.n0.trans)
mvar.clr <- mvar(clr.n0.trans)
df_pcx <- as.data.frame(pcx$x)
df_pcx$Strain <- c(rep("WT", 3), rep("ProAla", 3), rep("ArgSer", 3))
df_pcx$Sample <- rownames(df_pcx)
ggplot(df_pcx, aes(x = PC1, y = PC2, color = Strain, label = Sample)) + geom_point(size = 4) + xlab(paste("PC1 (", (round(sum(pcx$sdev[1]^2)/mvar.clr, 3)*100), "%)")) + ylab(paste("PC2 (", (round(sum(pcx$sdev[2]^2)/mvar.clr, 3)*100), "%)")) + scale_color_npg() + theme_bw()



## Proline to Alanine Mistranslating tRNA Analysis ##

# Read in data and select only WT and ProAla data
# Rename row names to the systematic gene name and remove column 1 with the same names
ProAla <- RawCounts %>%
  dplyr::select(Systematic, WT13, WT15, WT16, ProAla2, ProAla3, ProAla4)
rownames(ProAla) <- ProAla$Systematic
ProAla <- ProAla[-1]

# Organize the data for DESeq analysis
ProAla.DEseq <- ProAla
coldata <- data.frame(Sample = c("WT13", "WT15", "WT16", "ProAla2", "ProAla3", "ProAla4"), Condition = c(rep("WT", 3), rep("Mutant", 3)))

# Analysis with DESeq
ProAla.dds <- DESeqDataSetFromMatrix(countData = ProAla.DEseq, colData = coldata, design = ~Condition)
ProAla.dds.DE <- DESeq(ProAla.dds)
ProAla.results <- results(ProAla.dds.DE)

# Order results and summarize
ProAla.results.Ordered <- ProAla.results[order(ProAla.results$padj),]
summary(ProAla.results)

# Visualize results
plotMA(ProAla.results, ylim = c(-2,2))

# Organize data to make volcano plot
ProAla.plotting <- as.data.frame(ProAla.results) 
ProAla.plotting <- mutate(ProAla.plotting, Systematic = rownames(ProAla.plotting))%>%
  left_join(GeneNames, by = "Systematic") %>%
  dplyr::select(baseMean, log2FoldChange, lfcSE, stat, pvalue, padj, Systematic, Common)

# Create volcano plot of data
ggplot(ProAla.plotting, aes(x = -(log2FoldChange), y = -log10(padj), label = Common)) + geom_point(size = 2.35,color = if_else(ProAla.plotting$padj < 0.05 & ProAla.plotting$log2FoldChange > 1, "darkgreen", if_else(ProAla.plotting$padj < 0.05 & ProAla.plotting$log2FoldChange < -1, "darkgreen", "grey"))) + theme_bw(base_size = 16) + xlab("Log2(Fold Change)") + ylab("-Log10(Q-Value)") + geom_text_repel(data = subset(ProAla.plotting, (log2FoldChange > 1.5 & padj < 0.05)), nudge_x = -1, direction = "y", hjust = 0.5, segment.size = 0.2) + geom_text_repel(data = subset(ProAla.plotting, (log2FoldChange < -1.5 & padj < 0.05)), nudge_x = 2, direction = "y", hjust = 0.1, segment.size = 0.25)

# Create two data frames for up and down regulate genes
Allup.ProAla <- ProAla.plotting[(ProAla.plotting$padj < 0.05 & ProAla.plotting$log2FoldChange < -1),] %>%
  na.omit()
Alldn.ProAla <- ProAla.plotting[(ProAla.plotting$padj < 0.05 & ProAla.plotting$log2FoldChange > 1),] %>%
  na.omit()

# Export table of noramlized counts
ProAla.Normalizedcounts <- as.data.frame(counts(ProAla.dds.DE, normalize = T))
write.csv(ProAla.Normalizedcounts, "ProAla_NormalizedCounts.csv")



## Arginine to Serine Mistranslating tRNA Analysis ##

# Read in data and select only WT and ProAla data
# Rename row names to the systematic gene name and remove column 1 with the same names
ArgSer <- RawCounts %>%
  dplyr::select(Systematic, WT13, WT15, WT16, ArgSer5, ArgSer6, ArgSer7)
rownames(ArgSer) <- ArgSer$Systematic
ArgSer <- ArgSer[-1]

# Organize the data for DESeq analysis
ArgSer.DEseq <- ArgSer
coldata <- data.frame(Sample = c("WT13", "WT15", "WT16", "ArgSer5", "ArgSer6", "ArgSer7"), Condition = c(rep("WT", 3), rep("Mutant", 3)))

# Analysis with DESeq
ArgSer.dds <- DESeqDataSetFromMatrix(countData = ArgSer.DEseq, colData = coldata, design = ~Condition)
ArgSer.dds.DE <- DESeq(ArgSer.dds)
ArgSer.results <- results(ArgSer.dds.DE)

# Order results and summarize
ArgSer.results.Ordered <- ArgSer.results[order(ArgSer.results$padj),]
summary(ArgSer.results)

# Visualize results
plotMA(ArgSer.results, ylim = c(-2,2))

# Organize data to make volcano plot
ArgSer.plotting <- as.data.frame(ArgSer.results) 
ArgSer.plotting <- mutate(ArgSer.plotting, Systematic = rownames(ArgSer.plotting))%>%
  left_join(GeneNames, by = "Systematic") %>%
  dplyr::select(baseMean, log2FoldChange, lfcSE, stat, pvalue, padj, Systematic, Common)

# Create volcano plot of data
ggplot(ArgSer.plotting, aes(x = -(log2FoldChange), y = -log10(padj), label = Common)) + geom_point(size = 2.35,color = if_else(ArgSer.plotting$padj < 0.05 & ArgSer.plotting$log2FoldChange > 1, "blue", if_else(ArgSer.plotting$padj < 0.05 & ArgSer.plotting$log2FoldChange < -1, "blue", "grey"))) + theme_bw(base_size = 16) + xlab("Log2(Fold Change)") + ylab("-Log10(Q-Value)") + geom_text_repel(data = subset(ArgSer.plotting, (log2FoldChange > 1.5 & padj < 0.05)), nudge_x = -1, direction = "y", hjust = 0.5, segment.size = 0.2) + geom_text_repel(data = subset(ArgSer.plotting, (log2FoldChange < -1.5 & padj < 0.05)), nudge_x = 2, direction = "y", hjust = 0.1, segment.size = 0.25)

# Create two data frames for up and down regulate genes
Allup.ArgSer <- ArgSer.plotting[(ArgSer.plotting$padj < 0.05 & ArgSer.plotting$log2FoldChange < -1),] %>%
  na.omit()
Alldn.ArgSer <- ArgSer.plotting[(ArgSer.plotting$padj < 0.05 & ArgSer.plotting$log2FoldChange > 1),] %>%
  na.omit()

# Export table of noramlized counts
ArgSer.Normalizedcounts <- as.data.frame(counts(ArgSer.dds.DE, normalize = T))
write.csv(ArgSer.Normalizedcounts, "ArgSer_NormalizedCounts.csv")


## Heatmap of DEGs in Each Mistranslating Strain ##

# Select all the DEG in proline to alanine strain
ProAla.FoldChange <- ProAla.plotting %>%
  mutate(FoldChange = ifelse(padj < 0.05, log2FoldChange, 0)) %>%
  na.omit() %>%
  dplyr::select(Common, FoldChange)

# Select all the DEG in arginine to serine strain 
ArgSer.FoldChange <- ArgSer.plotting %>%
  mutate(FoldChange = ifelse(padj < 0.05, log2FoldChange, 0)) %>%
  na.omit() %>%
  dplyr::select(Common, FoldChange)

# Join the two datasets together to get one set of all differentially expressed genes
FoldChange <- full_join(ProAla.FoldChange, ArgSer.FoldChange, by = "Common")
colnames(FoldChange) <- c("Common", "ProAla", "ArgSer")
rownames(FoldChange) <- FoldChange$Common
FoldChange <- FoldChange[-1]

# Clean the data up to make the heat map and change fold change so genes that go up in mistranslating strain have positive fold changes and genes that go down have negative fold changes
CleanFoldChange <- t(FoldChange[which(rowSums(FoldChange) != 0), ])
FlipCleanFoldChange <- CleanFoldChange * -1

# Set up and create heatmap
breaks <- seq(-1, 1, by = 0.02)
HeatMap <- pheatmap(FlipCleanFoldChange, show_colnames = FALSE, col = colorRampPalette(c("dodgerblue2", "gray93", "gold"))(100), annotation_legend = FALSE, clustering_distance_cols = "euclidean", clustering_method = "ward.D", cutree_cols = 10, breaks = breaks)
